@@ -8,9 +8,10 @@ from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import DeclarativeMeta
 from sqlalchemy import Column, Boolean, DateTime
 
-from db.database import engine
 from dao import BaseDao
 
+from config.settings import DATABASE_SCHEMA
+
 
 class CustomDeclarativeMeta(DeclarativeMeta):
 
@@ -21,10 +22,12 @@ class CustomDeclarativeMeta(DeclarativeMeta):
                 self.objects = self.objects()
                 self.objects.model_cls = self
                 if getattr(self.objects.model_cls, "is_delete", False):
-                    self.objects.base_filter = (self.objects.model_cls.is_delete == 0, )
+                    self.objects.base_filter = (self.objects.model_cls.is_delete == 0,)
 
 
 Base = declarative_base(metaclass=CustomDeclarativeMeta)
+if DATABASE_SCHEMA:
+    Base.metadata.schema = DATABASE_SCHEMA
 
 
 class BaseModel(Base):
@@ -34,14 +37,10 @@ class BaseModel(Base):
     objects = BaseDao
     is_delete = Column(Boolean, nullable=False, default=False)
     create_time = Column(DateTime(3), default=datetime.now)
-    update_time = Column(DateTime(3), default=datetime.now)
+    update_time = Column(DateTime(3), default=datetime.now, onupdate=datetime.now)
 
     def to_dict(self, keys=None):
         if keys:
             return {c: getattr(self, c, None) for c in keys}
         else:
             return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}
-
-
-def create_tables():
-    Base.metadata.create_all(engine)
